#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class use_automatic_intersection_tolerance(Boolean):
    """
    Enable/disable using an automatic scaling of subtet intersection tolerance.
    """

    fluent_name = "use-automatic-intersection-tolerance?"

