#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class reset_pseudo_time_method_relaxations(Command):
    """
    'reset_pseudo_time_method_relaxations' command.
    """

    fluent_name = "reset-pseudo-time-method-relaxations"

