#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class cff_files(Boolean):
    """
    Indicate whether to write ANSYS common fluids format (CFF) files or legacy case and data files.
    """

    fluent_name = "cff-files?"

