#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class explicit_volume_fraction_under_relaxation(Real):
    """
    Set explicit volume fraction under-relaxation.
    """

    fluent_name = "explicit-volume-fraction-under-relaxation"

