#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class volumetric_synthetic_turbulence_generator_option(String):
    """
    'volumetric_synthetic_turbulence_generator_option' child.
    """

    fluent_name = "volumetric-synthetic-turbulence-generator-option"

