#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class is_not_a_rans_les_interface(Boolean):
    """
    'is_not_a_rans_les_interface' child.
    """

    fluent_name = "is-not-a-rans-les-interface"

