#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class cfl_type(Integer):
    """
    Set CFL type 
    [1]Convective   [2]Convective-Diffusive   [3]Acoustic   [4]Flow.
    """

    fluent_name = "cfl-type"

