#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class iterations(Integer):
    """
    Set the frequency (in iterations) at which cells in the register are automatically marked for poor mesh numerics treatment.
    """

    fluent_name = "iterations"

