#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class check_verbosity(Integer):
    """
    Set verbosity output of parallel check. Higher verbosity corresponds to more detailed information.
    """

    fluent_name = "check-verbosity"

