#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .species_child import species_child

class species(NamedObject[species_child], _NonCreatableNamedObjectMixin[species_child]):
    """
    'species' child.
    """

    fluent_name = "species"

    child_object_type: species_child = species_child
    """
    child_object_type of species.
    """
