#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class boundary_layer_tracking(Boolean):
    """
    Enable/disable adjusting the particle timestep to account for high aspect ratio cells.
    """

    fluent_name = "boundary-layer-tracking?"

