#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class prandtl_tuning_coefficient(Real):
    """
    Set the tuning coefficient in modified prandtl tip loss model:.
    """

    fluent_name = "prandtl-tuning-coefficient"

