#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class use_legacy_particle_location_method(Boolean):
    """
    Enable/disable legacy method of locating particles in cells.
    """

    fluent_name = "use-legacy-particle-location-method?"

