#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .visible import visible
from .size import size
from .color import color
from .log_scale import log_scale
from .format import format
from .user_skip import user_skip
from .show_all import show_all
from .position import position
from .font_name import font_name
from .font_automatic import font_automatic
from .font_size import font_size
from .length_1 import length
from .width import width
class color_map(Group):
    """
    'color_map' child.
    """

    fluent_name = "color-map"

    child_names = \
        ['visible', 'size', 'color', 'log_scale', 'format', 'user_skip',
         'show_all', 'position', 'font_name', 'font_automatic', 'font_size',
         'length', 'width']

    visible: visible = visible
    """
    visible child of color_map.
    """
    size: size = size
    """
    size child of color_map.
    """
    color: color = color
    """
    color child of color_map.
    """
    log_scale: log_scale = log_scale
    """
    log_scale child of color_map.
    """
    format: format = format
    """
    format child of color_map.
    """
    user_skip: user_skip = user_skip
    """
    user_skip child of color_map.
    """
    show_all: show_all = show_all
    """
    show_all child of color_map.
    """
    position: position = position
    """
    position child of color_map.
    """
    font_name: font_name = font_name
    """
    font_name child of color_map.
    """
    font_automatic: font_automatic = font_automatic
    """
    font_automatic child of color_map.
    """
    font_size: font_size = font_size
    """
    font_size child of color_map.
    """
    length: length = length
    """
    length child of color_map.
    """
    width: width = width
    """
    width child of color_map.
    """
