#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class time_step_size_for_solid_zone(Real):
    """
    Pseudo Time Step Size for solid zones.
    """

    fluent_name = "time-step-size-for-solid-zone"

