#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class smoothing_relaxation_factor(Real):
    """
    Set Smoothing relaxation factor (min : 0, max : 1).
    """

    fluent_name = "smoothing-relaxation-factor"

