#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class dpm_upper_deposition_limit_offset(Real):
    """
    'dpm_upper_deposition_limit_offset' child.
    """

    fluent_name = "dpm-upper-deposition-limit-offset"

