#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class create_particles_every_particle_step(Boolean):
    """
    Create particles every particle time step (else every fluid time step)?.
    """

    fluent_name = "create-particles-every-particle-step?"

