#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class sbes_sdes_hybrid_model_optn(String):
    """
    Select the SBES / SDES hybrid model.
    """

    fluent_name = "sbes-sdes-hybrid-model-optn"

