#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .material import material
from .sources import sources
from .source_terms_1 import source_terms
from .fixed import fixed
from .cylindrical_fixed_var import cylindrical_fixed_var
from .fixes import fixes
from .motion_spec import motion_spec
from .relative_to_thread import relative_to_thread
from .omega import omega
from .axis_origin_1 import axis_origin
from .axis_direction_1 import axis_direction
from .udf_zmotion_name import udf_zmotion_name
from .mrf_motion import mrf_motion
from .mrf_relative_to_thread import mrf_relative_to_thread
from .mrf_omega import mrf_omega
from .reference_frame_velocity import reference_frame_velocity
from .reference_frame_axis_origin import reference_frame_axis_origin
from .reference_frame_axis_direction import reference_frame_axis_direction
from .mrf_udf_zmotion_name import mrf_udf_zmotion_name
from .mgrid_enable_transient import mgrid_enable_transient
from .mgrid_motion import mgrid_motion
from .mgrid_relative_to_thread import mgrid_relative_to_thread
from .mgrid_omega import mgrid_omega
from .moving_mesh_velocity import moving_mesh_velocity
from .moving_mesh_axis_origin import moving_mesh_axis_origin
from .moving_mesh_axis_direction import moving_mesh_axis_direction
from .mgrid_udf_zmotion_name import mgrid_udf_zmotion_name
from .solid_motion import solid_motion
from .solid_relative_to_thread import solid_relative_to_thread
from .solid_omega import solid_omega
from .solid_motion_velocity import solid_motion_velocity
from .solid_motion_axis_origin import solid_motion_axis_origin
from .solid_motion_axis_direction import solid_motion_axis_direction
from .solid_udf_zmotion_name import solid_udf_zmotion_name
from .radiating import radiating
from .les_embedded import les_embedded
from .contact_property import contact_property
from .active_wetsteam_zone import active_wetsteam_zone
from .vapor_phase_realgas import vapor_phase_realgas
from .cursys import cursys
from .cursys_name import cursys_name
from .pcb_model import pcb_model
from .pcb_zone_info import pcb_zone_info
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['material', 'sources', 'source_terms', 'fixed',
         'cylindrical_fixed_var', 'fixes', 'motion_spec',
         'relative_to_thread', 'omega', 'axis_origin', 'axis_direction',
         'udf_zmotion_name', 'mrf_motion', 'mrf_relative_to_thread',
         'mrf_omega', 'reference_frame_velocity',
         'reference_frame_axis_origin', 'reference_frame_axis_direction',
         'mrf_udf_zmotion_name', 'mgrid_enable_transient', 'mgrid_motion',
         'mgrid_relative_to_thread', 'mgrid_omega', 'moving_mesh_velocity',
         'moving_mesh_axis_origin', 'moving_mesh_axis_direction',
         'mgrid_udf_zmotion_name', 'solid_motion', 'solid_relative_to_thread',
         'solid_omega', 'solid_motion_velocity', 'solid_motion_axis_origin',
         'solid_motion_axis_direction', 'solid_udf_zmotion_name', 'radiating',
         'les_embedded', 'contact_property', 'active_wetsteam_zone',
         'vapor_phase_realgas', 'cursys', 'cursys_name', 'pcb_model',
         'pcb_zone_info']

    material: material = material
    """
    material child of phase_child.
    """
    sources: sources = sources
    """
    sources child of phase_child.
    """
    source_terms: source_terms = source_terms
    """
    source_terms child of phase_child.
    """
    fixed: fixed = fixed
    """
    fixed child of phase_child.
    """
    cylindrical_fixed_var: cylindrical_fixed_var = cylindrical_fixed_var
    """
    cylindrical_fixed_var child of phase_child.
    """
    fixes: fixes = fixes
    """
    fixes child of phase_child.
    """
    motion_spec: motion_spec = motion_spec
    """
    motion_spec child of phase_child.
    """
    relative_to_thread: relative_to_thread = relative_to_thread
    """
    relative_to_thread child of phase_child.
    """
    omega: omega = omega
    """
    omega child of phase_child.
    """
    axis_origin: axis_origin = axis_origin
    """
    axis_origin child of phase_child.
    """
    axis_direction: axis_direction = axis_direction
    """
    axis_direction child of phase_child.
    """
    udf_zmotion_name: udf_zmotion_name = udf_zmotion_name
    """
    udf_zmotion_name child of phase_child.
    """
    mrf_motion: mrf_motion = mrf_motion
    """
    mrf_motion child of phase_child.
    """
    mrf_relative_to_thread: mrf_relative_to_thread = mrf_relative_to_thread
    """
    mrf_relative_to_thread child of phase_child.
    """
    mrf_omega: mrf_omega = mrf_omega
    """
    mrf_omega child of phase_child.
    """
    reference_frame_velocity: reference_frame_velocity = reference_frame_velocity
    """
    reference_frame_velocity child of phase_child.
    """
    reference_frame_axis_origin: reference_frame_axis_origin = reference_frame_axis_origin
    """
    reference_frame_axis_origin child of phase_child.
    """
    reference_frame_axis_direction: reference_frame_axis_direction = reference_frame_axis_direction
    """
    reference_frame_axis_direction child of phase_child.
    """
    mrf_udf_zmotion_name: mrf_udf_zmotion_name = mrf_udf_zmotion_name
    """
    mrf_udf_zmotion_name child of phase_child.
    """
    mgrid_enable_transient: mgrid_enable_transient = mgrid_enable_transient
    """
    mgrid_enable_transient child of phase_child.
    """
    mgrid_motion: mgrid_motion = mgrid_motion
    """
    mgrid_motion child of phase_child.
    """
    mgrid_relative_to_thread: mgrid_relative_to_thread = mgrid_relative_to_thread
    """
    mgrid_relative_to_thread child of phase_child.
    """
    mgrid_omega: mgrid_omega = mgrid_omega
    """
    mgrid_omega child of phase_child.
    """
    moving_mesh_velocity: moving_mesh_velocity = moving_mesh_velocity
    """
    moving_mesh_velocity child of phase_child.
    """
    moving_mesh_axis_origin: moving_mesh_axis_origin = moving_mesh_axis_origin
    """
    moving_mesh_axis_origin child of phase_child.
    """
    moving_mesh_axis_direction: moving_mesh_axis_direction = moving_mesh_axis_direction
    """
    moving_mesh_axis_direction child of phase_child.
    """
    mgrid_udf_zmotion_name: mgrid_udf_zmotion_name = mgrid_udf_zmotion_name
    """
    mgrid_udf_zmotion_name child of phase_child.
    """
    solid_motion: solid_motion = solid_motion
    """
    solid_motion child of phase_child.
    """
    solid_relative_to_thread: solid_relative_to_thread = solid_relative_to_thread
    """
    solid_relative_to_thread child of phase_child.
    """
    solid_omega: solid_omega = solid_omega
    """
    solid_omega child of phase_child.
    """
    solid_motion_velocity: solid_motion_velocity = solid_motion_velocity
    """
    solid_motion_velocity child of phase_child.
    """
    solid_motion_axis_origin: solid_motion_axis_origin = solid_motion_axis_origin
    """
    solid_motion_axis_origin child of phase_child.
    """
    solid_motion_axis_direction: solid_motion_axis_direction = solid_motion_axis_direction
    """
    solid_motion_axis_direction child of phase_child.
    """
    solid_udf_zmotion_name: solid_udf_zmotion_name = solid_udf_zmotion_name
    """
    solid_udf_zmotion_name child of phase_child.
    """
    radiating: radiating = radiating
    """
    radiating child of phase_child.
    """
    les_embedded: les_embedded = les_embedded
    """
    les_embedded child of phase_child.
    """
    contact_property: contact_property = contact_property
    """
    contact_property child of phase_child.
    """
    active_wetsteam_zone: active_wetsteam_zone = active_wetsteam_zone
    """
    active_wetsteam_zone child of phase_child.
    """
    vapor_phase_realgas: vapor_phase_realgas = vapor_phase_realgas
    """
    vapor_phase_realgas child of phase_child.
    """
    cursys: cursys = cursys
    """
    cursys child of phase_child.
    """
    cursys_name: cursys_name = cursys_name
    """
    cursys_name child of phase_child.
    """
    pcb_model: pcb_model = pcb_model
    """
    pcb_model child of phase_child.
    """
    pcb_zone_info: pcb_zone_info = pcb_zone_info
    """
    pcb_zone_info child of phase_child.
    """
