#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .accelerated_non_iterative_time_marching import accelerated_non_iterative_time_marching
from .convergence_acceleration_for_stretched_meshes import convergence_acceleration_for_stretched_meshes
from .discretization_scheme import discretization_scheme
from .expert_2 import expert
from .flux_type_2 import flux_type
from .frozen_flux import frozen_flux
from .gradient_scheme import gradient_scheme
from .high_order_term_relaxation import high_order_term_relaxation
from .multiphase_numerics import multiphase_numerics
from .nb_gradient_boundary_option import nb_gradient_boundary_option
from .nita_expert_controls import nita_expert_controls
from .noniterative_time_advance import noniterative_time_advance
from .overset_1 import overset
from .p_v_coupling_1 import p_v_coupling
from .phase_based_vof_discretization import phase_based_vof_discretization
from .reduced_rank_extrapolation import reduced_rank_extrapolation
from .reduced_rank_extrapolation_options import reduced_rank_extrapolation_options
from .residual_smoothing import residual_smoothing
from .unsteady_1st_order import unsteady_1st_order
from .unsteady_2nd_order import unsteady_2nd_order
from .unsteady_2nd_order_bounded import unsteady_2nd_order_bounded
from .unsteady_global_time import unsteady_global_time
from .vof_numerics import vof_numerics
from .warped_face_gradient_correction import warped_face_gradient_correction
from .pseudo_time_method import pseudo_time_method
from .set_solution_methods_to_default import set_solution_methods_to_default
class methods(Group):
    """
    'methods' child.
    """

    fluent_name = "methods"

    child_names = \
        ['accelerated_non_iterative_time_marching',
         'convergence_acceleration_for_stretched_meshes',
         'discretization_scheme', 'expert', 'flux_type', 'frozen_flux',
         'gradient_scheme', 'high_order_term_relaxation',
         'multiphase_numerics', 'nb_gradient_boundary_option',
         'nita_expert_controls', 'noniterative_time_advance', 'overset',
         'p_v_coupling', 'phase_based_vof_discretization',
         'reduced_rank_extrapolation', 'reduced_rank_extrapolation_options',
         'residual_smoothing', 'unsteady_1st_order', 'unsteady_2nd_order',
         'unsteady_2nd_order_bounded', 'unsteady_global_time', 'vof_numerics',
         'warped_face_gradient_correction', 'pseudo_time_method']

    accelerated_non_iterative_time_marching: accelerated_non_iterative_time_marching = accelerated_non_iterative_time_marching
    """
    accelerated_non_iterative_time_marching child of methods.
    """
    convergence_acceleration_for_stretched_meshes: convergence_acceleration_for_stretched_meshes = convergence_acceleration_for_stretched_meshes
    """
    convergence_acceleration_for_stretched_meshes child of methods.
    """
    discretization_scheme: discretization_scheme = discretization_scheme
    """
    discretization_scheme child of methods.
    """
    expert: expert = expert
    """
    expert child of methods.
    """
    flux_type: flux_type = flux_type
    """
    flux_type child of methods.
    """
    frozen_flux: frozen_flux = frozen_flux
    """
    frozen_flux child of methods.
    """
    gradient_scheme: gradient_scheme = gradient_scheme
    """
    gradient_scheme child of methods.
    """
    high_order_term_relaxation: high_order_term_relaxation = high_order_term_relaxation
    """
    high_order_term_relaxation child of methods.
    """
    multiphase_numerics: multiphase_numerics = multiphase_numerics
    """
    multiphase_numerics child of methods.
    """
    nb_gradient_boundary_option: nb_gradient_boundary_option = nb_gradient_boundary_option
    """
    nb_gradient_boundary_option child of methods.
    """
    nita_expert_controls: nita_expert_controls = nita_expert_controls
    """
    nita_expert_controls child of methods.
    """
    noniterative_time_advance: noniterative_time_advance = noniterative_time_advance
    """
    noniterative_time_advance child of methods.
    """
    overset: overset = overset
    """
    overset child of methods.
    """
    p_v_coupling: p_v_coupling = p_v_coupling
    """
    p_v_coupling child of methods.
    """
    phase_based_vof_discretization: phase_based_vof_discretization = phase_based_vof_discretization
    """
    phase_based_vof_discretization child of methods.
    """
    reduced_rank_extrapolation: reduced_rank_extrapolation = reduced_rank_extrapolation
    """
    reduced_rank_extrapolation child of methods.
    """
    reduced_rank_extrapolation_options: reduced_rank_extrapolation_options = reduced_rank_extrapolation_options
    """
    reduced_rank_extrapolation_options child of methods.
    """
    residual_smoothing: residual_smoothing = residual_smoothing
    """
    residual_smoothing child of methods.
    """
    unsteady_1st_order: unsteady_1st_order = unsteady_1st_order
    """
    unsteady_1st_order child of methods.
    """
    unsteady_2nd_order: unsteady_2nd_order = unsteady_2nd_order
    """
    unsteady_2nd_order child of methods.
    """
    unsteady_2nd_order_bounded: unsteady_2nd_order_bounded = unsteady_2nd_order_bounded
    """
    unsteady_2nd_order_bounded child of methods.
    """
    unsteady_global_time: unsteady_global_time = unsteady_global_time
    """
    unsteady_global_time child of methods.
    """
    vof_numerics: vof_numerics = vof_numerics
    """
    vof_numerics child of methods.
    """
    warped_face_gradient_correction: warped_face_gradient_correction = warped_face_gradient_correction
    """
    warped_face_gradient_correction child of methods.
    """
    pseudo_time_method: pseudo_time_method = pseudo_time_method
    """
    pseudo_time_method child of methods.
    """
    command_names = \
        ['set_solution_methods_to_default']

    set_solution_methods_to_default: set_solution_methods_to_default = set_solution_methods_to_default
    """
    set_solution_methods_to_default command of methods.
    """
